import * as React from 'react';
import * as zod from 'zod';
import { IFrameWindow } from '@crossmint/client-sdk-window';

declare function useSignerIFrameWindow(environment: string, url?: string): React.MutableRefObject<IFrameWindow<{
    readonly "response:create-signer": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodOptional<zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey?: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        } | undefined;
    }, {
        status: "success";
        publicKey?: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        } | undefined;
    }>]>;
    readonly "response:get-attestation": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        attestationDocument: zod.ZodRecord<zod.ZodString, zod.ZodAny>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        attestationDocument: Record<string, any>;
    }, {
        status: "success";
        attestationDocument: Record<string, any>;
    }>]>;
    readonly "response:send-otp": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }>]>;
    readonly "response:get-public-key": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }>]>;
    readonly "response:sign": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        publicKey: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
        signature: zod.ZodObject<{
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        }>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
        signature: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        };
    }, {
        status: "success";
        publicKey: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
        signature: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
        };
    }>]>;
    readonly "response:get-status": zod.ZodUnion<[zod.ZodObject<{
        status: zod.ZodLiteral<"error">;
        error: zod.ZodString;
        code: zod.ZodOptional<zod.ZodString>;
        data: zod.ZodOptional<zod.ZodAny>;
    }, "strip", zod.ZodTypeAny, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }, {
        status: "error";
        error: string;
        code?: string | undefined;
        data?: any;
    }>, zod.ZodObject<{
        signerStatus: zod.ZodEnum<["ready", "new-device"]>;
        status: zod.ZodLiteral<"success">;
    }, zod.UnknownKeysParam, zod.ZodTypeAny, {
        status: "success";
        signerStatus: "ready" | "new-device";
    }, {
        status: "success";
        signerStatus: "ready" | "new-device";
    }>]>;
}, {
    readonly "request:create-signer": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            authId: zod.ZodString;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            keyType: "secp256k1" | "ed25519";
            authId: string;
        }, {
            keyType: "secp256k1" | "ed25519";
            authId: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            authId: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            authId: string;
        };
    }>;
    readonly "request:get-attestation": zod.ZodObject<{
        challenge: zod.ZodString;
    }, "strip", zod.ZodTypeAny, {
        challenge: string;
    }, {
        challenge: string;
    }>;
    readonly "request:send-otp": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            encryptedOtp: zod.ZodString;
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            keyType: "secp256k1" | "ed25519";
            encryptedOtp: string;
        }, {
            keyType: "secp256k1" | "ed25519";
            encryptedOtp: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            encryptedOtp: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
            encryptedOtp: string;
        };
    }>;
    readonly "request:get-public-key": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
        }, "strip", zod.ZodTypeAny, {
            keyType: "secp256k1" | "ed25519";
        }, {
            keyType: "secp256k1" | "ed25519";
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            keyType: "secp256k1" | "ed25519";
        };
    }>;
    readonly "request:sign": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
        data: zod.ZodObject<{
            keyType: zod.ZodEnum<["secp256k1", "ed25519"]>;
            bytes: zod.ZodString;
            encoding: zod.ZodEnum<["base58", "base64", "hex"]>;
        }, "strip", zod.ZodTypeAny, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }, {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
        data: {
            bytes: string;
            encoding: "base58" | "base64" | "hex";
            keyType: "secp256k1" | "ed25519";
        };
    }>;
    readonly "request:get-status": zod.ZodObject<{
        authData: zod.ZodObject<{
            jwt: zod.ZodString;
            apiKey: zod.ZodString;
        }, "strip", zod.ZodTypeAny, {
            jwt: string;
            apiKey: string;
        }, {
            jwt: string;
            apiKey: string;
        }>;
    }, "strip", zod.ZodTypeAny, {
        authData: {
            jwt: string;
            apiKey: string;
        };
    }, {
        authData: {
            jwt: string;
            apiKey: string;
        };
    }>;
}> | null>;

export { useSignerIFrameWindow };
